# Ansible Collection - ibm.spectrum_virtualize

Due to brand renaming of IBM spectrum virtualize to storage virtualize, this collection is being discontinued and archived.

It is being replaced with new repository. The new collection is fully compatible with the old one. All the new features and development will be done on the new collection.
[ansible-collections/ibm.storage_virtualize](https://github.com/ansible-collections/ibm.storage_virtualize)
